Package: mitology
Type: Package
Title: Study of mitochondrial activity from RNA-seq data
Version: 1.5.0
Authors@R: c(person("Stefania", "Pirrotta", role = c("cre", "aut"),
                    email = "stefania.pirrotta@unipd.it",
                    comment = c(ORCID = "0009-0004-0030-217X")),
             person("Enrica", "Calura", role = c("aut", "fnd"), 
                    email = "enrica.calura@unipd.it",
                    comment = c(ORCID = "0000-0001-8463-2432")))
Description: mitology allows to study the mitochondrial activity throught
        high-throughput RNA-seq data. It is based on a collection of genes whose
        proteins localize in to the mitochondria. From these, mitology provides 
        a reorganization of the pathways related to mitochondria activity from 
        Reactome and Gene Ontology. Further a ready-to-use implementation of 
        MitoCarta3.0 pathways is included.
License: AGPL-3
biocViews: GeneExpression, RNASeq, Visualization, SingleCell, Spatial,
        Pathways, Reactome, GO
Imports: AnnotationDbi, ape, circlize, clusterProfiler, ComplexHeatmap,
        ggplot2, ggtree, magrittr, org.Hs.eg.db, ReactomePA, scales
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.5.0)
LazyData: false
Suggests: Biobase, BiocStyle, GSVA, methods, rmarkdown, knitr,
        SummarizedExperiment, testthat
VignetteBuilder: knitr
BugReports: https://github.com/CaluraLab/mitology/issues
URL: https://github.com/CaluraLab/mitology
git_url: https://git.bioconductor.org/packages/mitology
git_branch: devel
git_last_commit: 6b9bf15
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:52:25 UTC; biocbuild
Author: Stefania Pirrotta [cre, aut] (ORCID:
    <https://orcid.org/0009-0004-0030-217X>),
  Enrica Calura [aut, fnd] (ORCID:
    <https://orcid.org/0000-0001-8463-2432>)
Maintainer: Stefania Pirrotta <stefania.pirrotta@unipd.it>

# Generated by roxygen2: do not edit by hand

export(enrichMito)
export(getGeneSets)
export(gseaMito)
export(mitoHeatmap)
export(mitoTreeHeatmap)
export(mitoTreePoint)
import(ggplot2)
importFrom(AnnotationDbi,mapIds)
importFrom(ComplexHeatmap,Heatmap)
importFrom(ComplexHeatmap,HeatmapAnnotation)
importFrom(ComplexHeatmap,rowAnnotation)
importFrom(ReactomePA,enrichPathway)
importFrom(ReactomePA,gsePathway)
importFrom(ape,Ntip)
importFrom(ape,extract.clade)
importFrom(circlize,colorRamp2)
importFrom(clusterProfiler,GSEA)
importFrom(clusterProfiler,enrichGO)
importFrom(clusterProfiler,enricher)
importFrom(clusterProfiler,gseGO)
importFrom(ggtree,geom_cladelab)
importFrom(ggtree,geom_tiplab)
importFrom(ggtree,geom_tippoint)
importFrom(ggtree,ggtree)
importFrom(ggtree,gheatmap)
importFrom(magrittr,"%>%")
importFrom(org.Hs.eg.db,org.Hs.eg.db)
importFrom(scales,rescale)

mitology R package
================

<!-- README.md is generated from README.Rmd. Please edit that file -->

<img src=./vignettes/figures/puzzle_mitology.png width="200" align="right" />

Mitology is an R package to dissect mitochondrial activity from gene
expression data. We provide in R environment MitoCarta3.0 pathways and
we exploited Reactome pathways and GO hierarchies to derive and
re-organize mitochondrial-specific gene sets.

## Installation

The `mitology` package can be installed from Bioconductor:

``` r
if (!require("BiocManager", quietly = TRUE))
    install.packages("BiocManager")

BiocManager::install("mitology")
```

Also you can install the latest version of `mitology` from GitHub with:

``` r
library(remotes)
remotes::install_github("CaluraLab/mitology")
```

## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(echo = TRUE, fig.wide = TRUE)

## ----eval=FALSE---------------------------------------------------------------
# if (!require("BiocManager", quietly = TRUE))
#     install.packages("BiocManager")
# 
# BiocManager::install("mitology")

## -----------------------------------------------------------------------------
library(mitology)
data(MitoGenesDB)
head(MitoGenesDB)

## ----echo=FALSE, fig.wide=FALSE-----------------------------------------------
knitr::include_graphics("figures/MitoCarta_gene_sets.png")
# <img src=./figures/MitoCarta_gene_sets.png class="center" />

## ----echo=FALSE, fig.wide=FALSE-----------------------------------------------
knitr::include_graphics("figures/GO_gene_sets.png")
# <img src=./figures/GO_gene_sets.png class="center" />

## ----echo=FALSE, fig.wide=FALSE-----------------------------------------------
knitr::include_graphics("figures/Reactome_gene_sets.png")
# <img src=./figures/Reactome_gene_sets.png class="center" />

## ----message=FALSE------------------------------------------------------------
MC_df <- getGeneSets(
    database = "MitoCarta", nametype = "SYMBOL", objectType = "dataframe")

MC_list <- getGeneSets(
    database = "MitoCarta", nametype = "SYMBOL", objectType = "list")

## ----message=FALSE------------------------------------------------------------
# loading packages
library(SummarizedExperiment)
library(AnnotationDbi)
library(org.Hs.eg.db)
library(GSVA)
library(Biobase)

## -----------------------------------------------------------------------------
# load data
data(ovse)
ovse

## ----warning=FALSE------------------------------------------------------------
genes <- rownames(ovse)[elementMetadata(ovse)$PROvsIMR_FDR < 0.01]
genes <- mapIds(
    org.Hs.eg.db, keys = genes, column = "ENSEMBL",
    keytype = "SYMBOL", multiVals = "first")

enrichresMC <- enrichMito(genes = genes, database = "MitoCarta")
enrichresRT <- enrichMito(genes = genes, database = "Reactome")

## ----warning=FALSE------------------------------------------------------------
geneslFC <- elementMetadata(ovse)$PROvsIMR_logFC
names(geneslFC) <- rownames(ovse)
names(geneslFC) <- mapIds(
    org.Hs.eg.db, keys = names(geneslFC), column = "ENSEMBL",
    keytype = "SYMBOL", multiVals = "first")
geneslFC <- sort(geneslFC, decreasing = TRUE)
geneslFC <- geneslFC[!is.na(names(geneslFC))]

gsearesMC <- gseaMito(genes = geneslFC, database = "MitoCarta")
gsearesRT <- gseaMito(genes = geneslFC, database = "Reactome")

## -----------------------------------------------------------------------------
gsvaPar <- ssgseaParam(exprData = ovse, geneSets = MC_list)
res_ssGSEA <- gsva(gsvaPar)

## -----------------------------------------------------------------------------
mitoTreePoint(data = enrichresMC, database = "MitoCarta", pvalCutoff = .9, color = "pvalue")
mitoTreePoint(data = enrichresRT, database = "Reactome", pvalCutoff = .4, color = "pvalue")

## -----------------------------------------------------------------------------
res_ssGSEA_subtype <- do.call(
    cbind, lapply(unique(ovse$OV_subtype), function(x){
        rowMeans(assay(res_ssGSEA)[,ovse$OV_subtype==x])
    }))
colnames(res_ssGSEA_subtype) <- unique(ovse$OV_subtype)
rownames(res_ssGSEA_subtype) <- rownames(res_ssGSEA)
res_ssGSEA_subtype <- t(scale(t(res_ssGSEA_subtype)))

## ----fig.height=5.5, fig.width=4.5--------------------------------------------
mitoHeatmap(data = res_ssGSEA_subtype, database = "MitoCarta")

## ----fig.height=5.2, fig.width=5.5--------------------------------------------
mitoHeatmap(data = res_ssGSEA_subtype, database = "MitoCarta", splitSections = TRUE)

## ----message=FALSE------------------------------------------------------------
mitoTreeHeatmap(
    data = res_ssGSEA_subtype, database = "MitoCarta",
    labelNames = "leaves", font.size = 1)

## ----message=FALSE------------------------------------------------------------
mitoTreeHeatmap(
    data = res_ssGSEA_subtype, database = "MitoCarta",
    labelNames = "sections", font.size = 3)

## -----------------------------------------------------------------------------
sessionInfo()

#' Example expression data.
#'
#' This is an example dataset containing gene expression values (in normalized
#' counts) of 40 ovarian cancer (OVC) patients extracted
#' from the Cancer Genome Atlas (TCGA) database.
#' This dataset should be used only with example purpose.
#' RNA sequencing OVC data were retrieved using
#' \code{\link[curatedTCGAData]{curatedTCGAData}} package. Data were then
#' normalized with the \code{\link[EDASeq]{betweenLaneNormalization}} function.
#' To lighten the dataset, the \code{\link[signifinder]{consensusOVSign}}
#' function was computed, which return 4 different scores, one for each OVC
#' subtype (Chen et al, 2018, Clinical Cancer Research) and the 10 samples
#' with the highest scores were selected for each subgroup.
#' Further, only the mitochondrial genes included in mitology were kept.
#' Finally, the log fold change of the IMR versus the PRO samples were computed.
#' Further details in mitology/inst/scripts/howToGenerateOvse.Rmd.
#'
#' @docType data
#'
#' @usage data(ovse)
#'
"ovse"


#' Mitochondrial genes
#'
#' Here are listed all the final mitochondrial genes in ENSEMBL id, the 
#' corresponding SYMBOL id and the database from where they were collected.
#'
#' @docType data
#' 
#' @usage data(MitoGenesDB)
#' 
"MitoGenesDB"

#' Get the mitochondrial gene sets
#'
#' @description It returns the mitochondrial gene sets (in form of list or 
#' data frame) of the four possible databases: "MitoCarta", "Reactome", 
#' "GO-CC" and "GO-BP".
#'
#' @param database character string saying the database to use for the analysis.
#' Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".
#' @param nametype character string saying the type of gene name ID. 
#' Either one of "SYMBOL", "ENTREZID" or "ENSEMBL".
#' @param objectType character string saying the type of needed object. 
#' Either one of "list" or "dataframe".
#' @param sections logical. Either to keep the aggregated gene set categories 
#' or the specific gene sets. Default is FALSE.
#'
#' @importFrom ape extract.clade
#' 
#' @return the mitochondrial gene sets.
#'
#' @examples
#' MClist <- getGeneSets()
#'
#' @export
getGeneSets <- function(
        database = "MitoCarta", nametype = "ENSEMBL", 
        objectType = "list", sections = FALSE){
    
    .consistencyCheck(
        database = database, nametype = nametype, 
        objectType = objectType, sections = sections)
    
    geneset <- .DBgeneset(database)
    geneset <- .geneIDtrans(nametype, geneset, database)
    
    if(sections){
        dbtree <- .DBtree(database)
        CatNodes <- dbtree$edge[,2][dbtree$edge[,1]==length(dbtree$tip.label)+1]
        geneset <- lapply(CatNodes, function(x){
            clade <- extract.clade(dbtree, node = x)
            unique(unname(unlist(geneset[clade$tip.label])))})
        names(geneset) <- dbtree$node.label[CatNodes-length(dbtree$tip.label)]}
    
    if(objectType == "dataframe"){
        geneset <- do.call(rbind, lapply(seq_along(geneset), function(i){
            data.frame(
                term = rep(names(geneset)[i], length(geneset[[i]])),
                gene = geneset[[i]]) }))}
    
    return(geneset)
}


#' Circular heatmap on mitochondrial gene set tree.
#'
#' @description Given a matrix of scores, it returns a circular heatmap of
#' the mitochondrial gene sets (leaf of the database tree) or gene set 
#' groups (section of the database tree).
#'
#' @param data matrix or data.frame with samples in columns and mitochondrial 
#' gene sets in rows.
#' @param database character string saying the database used for the analysis.
#' Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".
#' @param sections logical. Either to keep the aggregated gene set categories 
#' or the specific gene sets. Default is FALSE.
#' @param samples character vector with the names of samples to be plotted.
#' Otherwise all samples are plotted.
#' @param labelNames character string that says to plot either the names of 
#' "sections" or "leaves".
#' @param ... other arguments passed on to the \code{\link[ggtree]{gheatmap}}
#' function.
#'
#' @return A \code{\link[ggplot2]{ggplot}} object.
#'
#' @importFrom ggtree ggtree gheatmap geom_tiplab geom_cladelab
#' @importFrom scales rescale
#' @importFrom ape extract.clade Ntip
#' @importFrom magrittr %>%
#' @import ggplot2
#'
#' @examples
#' MClist <- getGeneSets()
#' n <- length(names(MClist)) * 5
#' rmatrix <- matrix(rnorm(n, 0), ncol = 5)
#' rownames(rmatrix) <- names(MClist)
#' colnames(rmatrix) <- paste0("Sample_", seq_len(5))
#' mitoTreeHeatmap(data = rmatrix, database = "MitoCarta")
#'
#' @export
mitoTreeHeatmap <- function(
        data, database = "MitoCarta", sections = FALSE, 
        samples = NULL, labelNames = "sections", ...){

    .consistencyCheck(
        database = database, sections = sections, labelNames = labelNames)

    dbtree <- .DBtree(database = database)
    dbdend <- ggtree(
        tr = dbtree, layout = "fan", open.angle = 25, color = "gray60")

    if(is.null(samples)){samples <- colnames(data)
    } else if(length(samples)<2){stop("Samples must be at least 2")
    } else if(!(all(samples %in% colnames(data)))){
        stop("All samples must be included in data")}
    data <- data[,colnames(data) %in% samples]
    CatNodes <- dbtree$edge[,2][dbtree$edge[,1]==length(dbtree$tip.label)+1]
    if(sections){
        data <- do.call(rbind, lapply(seq_along(CatNodes), function(x){
            clade <- extract.clade(dbtree, node = CatNodes[x])
            data[rep(x, length(clade$tip.label)),]}))
        rownames(data) <- dbtree$tip.label }
    plotPar <- .plotParams(database = database)
    dots <- list(...)
    args <- .matchArguments(dots, list(
        p = dbdend, data = data, colnames = TRUE, 
        colnames_angle = 30, colnames_position = "top", hjust = 0, offset = 0))
    g <- do.call(gheatmap, args)
    maxScore <- max(abs(data))
    g <- g + scale_fill_gradientn(
        colours = c("#701d46","#CB347F", "white", plotPar$DBcol),
        name = "ssGSEA\nScore", limits = c(-maxScore, maxScore), 
        values = rescale(c(-maxScore, 0, maxScore)), na.value = "gray90") +
        theme(legend.position = "bottom")
    dbwidth <- (dbdend$data$x %>% range(na.rm=TRUE) %>% diff) / ncol(data)
    if(labelNames == "leaves" & !sections){
        g <- g + geom_tiplab(offset = dbwidth*(ncol(data)+1))
    } else {
        CatNames <- dbtree$node.label[CatNodes-Ntip(dbtree)]
        g <- g + geom_cladelab(
            node = CatNodes, label = CatNames, barsize = 2, 
            offset.text = (g$data$x[1]/5)/4, 
            offset = (g$data$x[1]/5)*(ncol(data)+2), 
            barcolour = plotPar$DBcol[1], angle = "auto", horizontal = TRUE) +
            theme(legend.key.size = unit(5, "mm")) }
    return(g)
}


#' Heatmap of mitochondrial gene sets.
#'
#' @description Given a matrix of scores, it returns a heatmap of
#' the mitochondrial gene sets.
#'
#' @param data matrix or data.frame with samples in columns and mitochondrial 
#' gene sets in rows.
#' @param database character string saying the database used for the analysis.
#' Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".
#' @param sampleAnnot character vector with samples' annotation.
#' @param splitSamples logical. If TRUE it splits samples by annotation.
#' sampleAnnot must be provided.
#' @param splitSections logical. If TRUE it splits gene sets by main section.
#' @param ... other parameters specific of the function
#' \code{\link[ComplexHeatmap]{Heatmap}}.
#'
#' @return A \code{\link[ComplexHeatmap]{Heatmap-class}} object.
#'
#' @importFrom ape extract.clade
#' @importFrom ComplexHeatmap Heatmap rowAnnotation HeatmapAnnotation
#' @importFrom circlize colorRamp2
#'
#' @examples
#' MClist <- getGeneSets()
#' n <- length(names(MClist)) * 5
#' rmatrix <- matrix(rnorm(n, 0), ncol = 5)
#' rownames(rmatrix) <- names(MClist)
#' colnames(rmatrix) <- paste0("Sample_", seq_len(5))
#' mitoHeatmap(data = rmatrix, database = "MitoCarta")
#'
#' @export
mitoHeatmap <- function(
        data, database = "MitoCarta", sampleAnnot = NULL, 
        splitSamples = FALSE, splitSections = FALSE, ...){
    
    if(!(database %in% c("MitoCarta", "Reactome", "GO-CC", "GO-BP"))){
        stop("Database has to be MitoCarta, Reactome, GO-CC or GO-BP")}
    if (!is.null(sampleAnnot)) { if (length(sampleAnnot)!=ncol(data)) {
        stop("sampleAnnot length is different than samples dimension")}
    } else { if (splitSamples) { stop(
        "splitSamples can be TRUE only if sampleAnnot is provided")}}
    
    dbtree <- .DBtree(database = database)
    
    CatNodes <- dbtree$edge[,2][dbtree$edge[,1]==length(dbtree$tip.label)+1]
    CatAnnot <- unlist(lapply(seq_along(CatNodes), function(x){
        clade <- extract.clade(dbtree, node = CatNodes[x])
        rep(clade$node.label[1], length(clade$tip.label))}))
    CatAnnot <- CatAnnot[match(rownames(data), dbtree$tip.label)]
    
    plotPar <- .plotParams(database = database)
    mycol <- colorRamp2(
        c(min(data), mean(c(min(data),0)), 0, mean(c(max(data),0)), max(data)), 
        c("#701d46","#CB347F", "white", plotPar$DBcol))
    
    dots <- list(...)
    args <- .matchArguments(dots, list(
        matrix = data, name = "score", show_row_names = FALSE, col = mycol))
    
    if(splitSections){
        args$row_split <- CatAnnot
        args$row_title_rot <- 0
    } else {
        ha <- rowAnnotation(Section = CatAnnot)
        args$right_annotation <- ha }
    
    if (!is.null(sampleAnnot)) {
        if (splitSamples) {
            args$column_split <- sampleAnnot
        } else {
            hatop <- HeatmapAnnotation(sampleAnnot = sampleAnnot)
            args$top_annotation <- hatop}}
    
    g <- do.call(Heatmap, args)
    return(g)
}


#' Mitochondrial Enrichment Analysis of a gene list.
#' 
#' @description Given a vector of genes, this function will return the 
#' enrichment analysis for the mitochondrial gene sets after FDR control. For 
#' the Reactome, GO-CC and GO-BP databases it returns also the enrichment 
#' results for the corresponding original pathways.
#'
#' @param genes a vector of gene ENSEMBL id.
#' @param database character string saying the database to use for the analysis.
#' Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".
#'
#' @importFrom clusterProfiler enricher enrichGO
#' @importFrom AnnotationDbi mapIds
#' @importFrom org.Hs.eg.db org.Hs.eg.db
#' @importFrom ReactomePA enrichPathway
#' 
#' @return enrichment analysis for the mitochondrial gene sets.
#' 
#' @examples
#' data(ovse)
#' 
#' @export
enrichMito <- function(genes, database){
    DB_df <- getGeneSets(database = database, objectType = "dataframe")
    orM <- enricher(gene = genes, TERM2GENE = DB_df, universe = MitoGenes)
    orM <- orM@result
    
    if(database == "MitoCarta"){ return(list(MitoCarta = orM)) }
    
    if(database == "Reactome"){
        genes <- mapIds(
            x = org.Hs.eg.db, keys = genes, 
            column = "ENTREZID", keytype = "ENSEMBL")
        orO <- enrichPathway(gene = genes, maxGSSize = 1000, readable = TRUE)
        orO <- orO@result
        orO$Description <- .mitologyName(names = orO$Description, database)
    } else {
        orO <- enrichGO(
            gene = genes, keyType = "ENSEMBL", OrgDb = "org.Hs.eg.db", 
            ont = substring(database, 4, 5), pAdjustMethod = "BH", 
            readable = TRUE, pvalueCutoff = 1.1, qvalueCutoff = 1.1,
            minGSSize = 10, maxGSSize = 100000)
        orO <- orO@result
        orO$Description <- .mitologyName(names = orO$Description, "GO")
    }
    
    orO <- orO[orO$Description %in% unique(DB_df$term),]
    or <- list(orM, orO)
    names(or) <- c("mitology", "original")
    return(or)
}


#' Mitochondrial GSEA of a gene list.
#' 
#' @description Gene set enrichment analysis for the mitochondrial gene sets. 
#' For the Reactome, GO-CC and GO-BP databases it returns also the GSEA 
#' results for the corresponding original pathways.
#'
#' @param genes order ranked gene vector named by ENSEMBL id.
#' @param database character string saying the database to use for the analysis.
#' Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".
#'
#' @importFrom clusterProfiler GSEA gseGO
#' @importFrom AnnotationDbi mapIds
#' @importFrom org.Hs.eg.db org.Hs.eg.db
#' @importFrom ReactomePA gsePathway
#' 
#' @return GSEA results for the mitochondrial gene sets.
#' 
#' @examples
#' data(ovse)
#' 
#' @export
gseaMito <- function(genes, database){
    DB_df <- getGeneSets(database = database, objectType = "dataframe")
    orM <- GSEA(geneList = genes, TERM2GENE = DB_df)
    orM <- orM@result
    
    if(database == "MitoCarta"){ return(list(MitoCarta = orM)) }
    
    if(database == "Reactome"){
        names(genes) <- mapIds(
            x = org.Hs.eg.db, keys = names(genes), 
            column = "ENTREZID", keytype = "ENSEMBL")
        genes <- genes[!is.na(names(genes))]
        genes <- genes[!duplicated(names(genes))]
        orO <- gsePathway(geneList = genes, maxGSSize = 1000)
        orO <- orO@result
        orO$Description <- .mitologyName(names = orO$Description, database)
    } else {
        orO <- gseGO(
            geneList = genes, keyType = "ENSEMBL", OrgDb = "org.Hs.eg.db", 
            ont = substring(database, 4, 5), pAdjustMethod = "BH", 
            pvalueCutoff = 1.1, minGSSize = 10, maxGSSize = 100000)
        orO <- orO@result
        orO$Description <- .mitologyName(names = orO$Description, "GO")
    }
    orO <- orO[orO$Description %in% unique(DB_df$term),]
    or <- list(orM, orO)
    names(or) <- c("mitology", "original")
    return(or)
}


#' Circular dotplot on mitochondrial gene set tree.
#'
#' @description A circular dotplot of the mitochondrial enrichment results.
#' 
#' @param data named list of the result from enrichMito or gseaMito.
#' @param database character string saying the database to use for the analysis.
#' Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".
#' @param pvalCutoff pvalue cutoff to select enriched gene sets
#' @param labsize label size
#' @param max_point_size max point size
#' @param color variable used to color enriched terms, e.g. 'pvalue', 
#' 'p.adjust' or 'NES'.
#' 
#' @importFrom ggtree ggtree geom_tippoint geom_tiplab
#' @import ggplot2
#' 
#' @return A \code{\link[ggplot2]{ggplot}} object.
#' 
#' @examples
#' data(ovse)
#' 
#' @export
mitoTreePoint <- function(
    data, database = "MitoCarta", pvalCutoff = 0.05, 
    labsize = 3, max_point_size = 4, color = "p.adjust"){
    
    .consistencyCheck(database = database)
    plotPar <- .plotParams(database = database)
    dbtree <- .DBtree(database = database)
    g <- ggtree(tr = dbtree, layout = "fan", open.angle = 25, color = "gray60")
    
    sampleGroup <- names(data)
    data <- lapply(data, function(x) x[x$Description %in% dbtree$tip.label,])
    data <- lapply(data, function(x) x[x$p.adjust < pvalCutoff,])
    if(sum(unlist(lapply(data, function(x) nrow(x))))<1){
        stop("There are no gene sets with a p.adjust under the pvalCutoff")}
    names(data) <- sampleGroup
    
    for(i in seq_along(data)){
        g$data[, paste(color, i, sep = "_")] <- NA
        g$data[match(data[[i]]$Description, dbtree$tip.label), 
               paste(color, i, sep = "_")] <- data[[i]][,color]
        g$data[, paste("count", i, sep = "_")] <- NA
        g$data[match(data[[i]]$Description, dbtree$tip.label), 
               paste("count", i, sep = "_")] <- data[[i]][
                   ,grepl(pattern = "Count", colnames(data[[i]])) | 
                       grepl(pattern = "setSize", colnames(data[[i]]))]}
    
    xpos <- g$data$x[1] + (g$data$x[1]/5)*(seq_along(data)-1)
    
    for(i in seq_along(data)){
        g <- g + geom_tippoint(aes(
            colour = .data[[paste(color, i, sep = "_")]], 
            size = .data[[paste("count", i, sep = "_")]]), 
            x = xpos[i])}
    
    g <- g + geom_text(aes(
        x = c(xpos, rep(NA, nrow(g$data)-length(data))), 
        label = c(sampleGroup, rep(NA, nrow(g$data)-length(data))), 
        y = 0), angle = -45, hjust = 0, size = labsize)
    g$data[-match(unique(unlist(lapply(data, function(x) x$Description))), 
                  dbtree$tip.label), "label"] <- NA
    g <- g + geom_tiplab(
        offset = (g$data$x[1]/5)*(length(data)-.6), size = labsize)
    
    g <- g + scale_size_continuous(name = "", range = c(1, max_point_size)) +
        scale_colour_viridis_c(name = color) +
        theme_minimal() +
        theme(legend.position = "bottom", 
              axis.line.y = element_blank(), axis.text = element_blank(), 
              panel.grid.minor.y = element_blank(), 
              panel.grid.major.y = element_blank(), 
              panel.grid.major.x = element_line(colour = c(
                  NA, rep("grey90", length(xpos)-1), NA))) + 
        scale_x_continuous(breaks = xpos)
    
    return(g)
}

library(mitology)
library(testthat)

test_that("mitoTreeHeatmap work", {
    n <- length(names(MCgs)) * 5
    rmatrix <- matrix(rnorm(n, 0), ncol = 5)
    rownames(rmatrix) <- names(MCgs)
    colnames(rmatrix) <- paste0("Sample_", seq_len(5))
    pres <- mitoTreeHeatmap(data = rmatrix, database = "MitoCarta")
    expect_true(is(pres, "ggtree"))
    expect_true(is(pres, "gg"))
    expect_true(is(pres, "ggplot"))
})

test_that("mitoHeatmap work", {
    n <- length(names(MCgs)) * 5
    rmatrix <- matrix(rnorm(n, 0), ncol = 5)
    rownames(rmatrix) <- names(MCgs)
    colnames(rmatrix) <- paste0("Sample_", seq_len(5))
    pres <- mitoHeatmap(data = rmatrix, database = "MitoCarta")
    expect_true(is(pres, "Heatmap"))
})

library(mitology)
library(testthat)

test_that("getGeneSets work", {
    dbnames <- c("MitoCarta", "Reactome", "GO-CC", "GO-BP")
    pname <- sample(dbnames, 1)
    
    res <- getGeneSets(database = pname)
    
    expect_true(is(res, "list"))
    expect_type(res[[1]], "character")
})

.consistencyCheck <- function(
        database = "MitoCarta", nametype = "ENSEMBL", objectType = "list", 
        sections = FALSE, labelNames = "sections") {
    if(!(database %in% c("MitoCarta", "Reactome", "GO-CC", "GO-BP"))){
        stop("Database has to be MitoCarta, Reactome, GO-CC or GO-BP")}
    if (!(nametype %in% c("SYMBOL", "ENTREZID", "ENSEMBL"))) {
        stop("The name of genes must be either SYMBOL, ENTREZID or ENSEMBL")}
    if(!(objectType %in% c("list", "dataframe"))){
        stop("Database has to be list or dataframe")}
    if(!is.logical(sections)){ stop("sections must be logical") }
    if(labelNames != "leaves" & labelNames != "sections"){
        stop("Label names must be leaves or sections")}
}

.DBgeneset <- function(database){
    if (database == "MitoCarta") {MCgs
    } else if (database == "Reactome") {RTgs
    } else if (database == "GO-CC") {CCgs
    } else if (database == "GO-BP") {BPgs}}

#' @importFrom AnnotationDbi mapIds
#' @importFrom org.Hs.eg.db org.Hs.eg.db
.geneIDtrans <- function(nametype, genes, database) {
    if (nametype != "ENSEMBL") { 
        if(nametype == "SYMBOL" & database == "MitoCarta"){
            converted_genes <- lapply(genes, function(g){ names(g) })
        } else {
            converted_genes <- lapply(genes, function(g){ mapIds(
                org.Hs.eg.db, keys = g, column = nametype, 
                keytype = "ENSEMBL", multiVals = "first") })}
        names(converted_genes) <- names(genes)
        return(converted_genes)
    } else { genes }
}

.DBtree <- function(database){
    if (database == "MitoCarta") {MCtree
    } else if (database == "Reactome") {RTtree
    } else if (database == "GO-CC") {CCtree
    } else if (database == "GO-BP") {BPtree}}

.plotParams <- function(database){
    if (database == "MitoCarta") {
        DBcol <- c("#823cef", "#2f0967"); hjust <- c(1,0,1,1,0,0,0)
    } else if (database == "Reactome") {
        DBcol <- c("#36ABC9", "#1d5b6b")
        hjust <- c(0,0,0,1,0,0,0,1,1,.5,0,1,1,0,0,1,0,1,0,0)
    } else if (database == "GO-CC") {
        DBcol <- c("#ECC300", "#866f00"); hjust <- c(0,1,0)
    } else if (database == "GO-BP") {
        DBcol <- c("#34CB80", "#1b6a43"); hjust <- c(1,1,rep(0, 10))}
    return(list(DBcol = DBcol, hjust = hjust))}

.matchArguments <- function(dots, defaults) {
    defaults[names(defaults) %in% names(dots)] <- NULL
    c(defaults, dots)
}

# convert DB names
.mitologyName <- function(names, database){
    if(database == "Reactome"){
        names <- gsub(" ", "_", names)
        names <- gsub("(,|\\(|\\))", "", names)
        names <- gsub("\\/", "-", names)
    } else if(database == "GO"){
        names <- gsub(" |,", "_", names)}
    return(names)
}

library(mitology)
library(testthat)

test_that(".DBgeneset works", {
    dbnames <- c("MitoCarta", "Reactome", "GO-CC", "GO-BP")
    dbname <- sample(dbnames, 1)
    res <- .DBgeneset(database = dbname)
    expect_true(is(res, "list"))
    expect_type(res[[1]], "character")
})

test_that(".geneIDtrans works", {
    dbnames <- c("MitoCarta", "Reactome", "GO-CC", "GO-BP")
    dbname <- sample(dbnames, 1)
    idnames <- c("SYMBOL", "ENTREZID", "ENSEMBL")
    idname <- sample(idnames, 1)
    res <- .DBgeneset(database = dbname)
    res <- .geneIDtrans(nametype = idname, genes = res, database = dbname)
    expect_true(is(res, "list"))
    expect_type(res[[1]], "character")
})

test_that(".DBtree works", {
    dbnames <- c("MitoCarta", "Reactome", "GO-CC", "GO-BP")
    dbname <- sample(dbnames, 1)
    res <- .DBtree(database = dbname)
    expect_true(is(res, "phylo"))
})

test_that(".plotParams works", {
    dbnames <- c("MitoCarta", "Reactome", "GO-CC", "GO-BP")
    dbname <- sample(dbnames, 1)
    res <- .plotParams(database = dbname)
    expect_true(is(res, "list"))
    expect_type(res[[1]], "character")
    expect_type(res[[2]], "double")
})

---
title: "mitology vignette"
author:
- name: Stefania Pirrotta
  affiliation: 
  - &id Biology Department, University of Padova, Italy
  email: stefania.pirrotta@unipd.it
package: mitology
abstract: >
  mitology allows to explore the mitochondrial activity through transcriptomic profiles. It is based on a collection of genes whose proteins localize in to the mitochondria, derived from specialized databases: MitoCarta3.0 [1], IMPI [2], MSeqDR [3], and Gene Ontology [4] (genes annotated with terms related to 'mitochondri-' in their description). Then, mitology provides ready-to-use implementations of MitoCarta3.0 pathways and also a reorganization of the pathways related to mitochondria activity from Reactome [5] and Gene Ontology. These mitochondria-focused pathways can be used to conduct mitochondrial-oriented pathway analyses, enabling single-sample assessments.
output:
  BiocStyle::html_document:
      toc: true
      toc_depth: 2
      toc_float:
          collapsed: true
vignette: >
  %\VignetteIndexEntry{mitology vignette}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(echo = TRUE, fig.wide = TRUE)
```

# Introduction
Mitochondria are cellular organelles whose main role is related to the aerobic respiration to supply energy to the cell. In addition to this, they are also involved in other tasks, such as signaling, cellular differentiation, and cell death, as well as maintaining control of the cell cycle and cell growth. The dysfunction of mitochondria activity has been implicated in several human disorders and conditions. Studying mitochondrial behavior in health and disease conditions is opening new possibilities of understanding disease mechanisms and providing new treatments. Indeed, the possibility to target mitochondria for cancer therapies is increasingly becoming a reality in biomedical research.

The analysis of high resolution transcriptomic data can help in better understanding mitochondrial activity in relation to the gene expression dynamics. Even if a curated mitochondrial specific pathway resource exists (MitoCarta3.0, which provides a list of mitochondrial genes organized into mitochondrial pathways [1]) computational tools for mitochondrial-focused pathway analysis are still lacking. In the field of gene set analysis, general purpose resources are pathway databases, such as Reactome [5] and the Gene Ontology (GO) project [4], which aim at providing gene set categories for high-throughput data analysis for all the cellular contexts. In the vast majority of pathways contained in these public databases, the mitochondrial-specific component of cellular signaling constitutes only a small portion, which is often overshadowed by the non-mitochondrial signaling. And, even if the information on protein localization is present, pathway analysis typically does not account for whether the activated signal involves the mitochondrion or not.

Thus, we thought that a tool able to focus specifically on the mitochondrial part of pathways could allow tailored and more specific analysis on this interesting organelle and we started to develop mitology to provide actionable and fast mitochondrial phenodata interpretation of high-throughput data.

These vignete shows some ways to perform mitochondrial pathway analyses using mitology. Also, some visualization functions are implemented to visualize the scores. These can help in the result interpretations.

# Installation
To install this package:

```{r eval=FALSE}
if (!require("BiocManager", quietly = TRUE))
    install.packages("BiocManager")

BiocManager::install("mitology")
```

# Mitochondrial Genes
A list of mitochondrial genes was obtained by joining four public resources that were developed in the last years to define the mitochondrial proteome with the aim to study mitochondrial functions, dysfunctions and diseases. Specifically, we collected the genes from: MitoCarta3.0 [1], the Integrated Mitochondrial Protein Index (IMPI) [2], the Mitochondrial Disease Sequence Data Resource (MSeqDR) [3] and The Gene Ontology (GO) [4].

In the MitoGenesDB table we can see the full list of genes along with the database from which it was retrieved.

```{r}
library(mitology)
data(MitoGenesDB)
head(MitoGenesDB)
```

# Gene sets collected in mitology
## Gene sets from MitoCarta3.0
The whole and original structure from the MitoCarta3.0 database was kept and included in mitology organized in a three-tier hierarchy.


```{r, echo=FALSE, fig.wide=FALSE}
knitr::include_graphics("figures/MitoCarta_gene_sets.png")
# <img src=./figures/MitoCarta_gene_sets.png class="center" />
```


In addition to MitoCarta3.0, we decided to propose three more comprehensive mitochondrial-oriented gene set resources exploiting Reactome, GO Biological Processes (GO-BP), and GO Cellular Components (GO-CC).

## Gene sets from GO
We explored the GO-CC and GO-BP terms. To filter the GO terms we performed a four-steps selection. Firstly, terms were filtered by size, keeping all the ones with at least 10 mitochondrial genes. Then, we pruned the GO trees of CC and BP by the graph levels, filtering out the 0°, 1°, 2° and 3° levels and keeping the terms from the 4° level. Then, we tested the enrichment of the remaining sets for our mitochondrial gene list with the `enrichGO` function from the `clusterProfiler` R package (v4.14.3). Only sets with FDR lower than 0.05 have been passed to the next step. Finally, the last selection was topological, we exploited the GO hierarchical organization selecting the more general enriched gene sets filtering out their offspring terms.


```{r, echo=FALSE, fig.wide=FALSE}
knitr::include_graphics("figures/GO_gene_sets.png")
# <img src=./figures/GO_gene_sets.png class="center" />
```


## Gene sets from Reactome
The Reactome pathways were retrieved with the `graphite` R package (v1.52.0). Reactome has a simpler structure with far less level of nested pathways, thus we applied only three filtering steps: number of mitochondrial genes over 10; FDR under 0.05 (enrichment computed with the `phyper` function) and filtering of the offspring pathways.


```{r, echo=FALSE, fig.wide=FALSE}
knitr::include_graphics("figures/Reactome_gene_sets.png")
# <img src=./figures/Reactome_gene_sets.png class="center" />
```


Once we obtained the final terms and pathways respectively from GO and Reactome, we extracted the mitochondrial gene sets by keeping only the genes included in the mitochondrial list. The same names of the original terms/pathways were kept for the gene sets included in mitology. The final gene sets and the corresponding tree-structures of the four databases were kept and included in the mitology package.

# How to use mitology
## Access mitochondrial gene sets
The `getGeneSets` function allows to get the mitochondrial gene sets. It returns them for one of the four possible databases (MitoCarta, Reactome, GO-CC and GO-BP) by the `database` argument. The `nametype` argument says the type of gene name ID, either one of SYMBOL, ENTREZID or ENSEMBL. The `objectType` argument can be set to return the gene sets in form of a list or a data frame.

```{r, message=FALSE}
MC_df <- getGeneSets(
    database = "MitoCarta", nametype = "SYMBOL", objectType = "dataframe")

MC_list <- getGeneSets(
    database = "MitoCarta", nametype = "SYMBOL", objectType = "list")
```

## Enrichment analyses
In the following section, we use an example bulk expression dataset of ovarian cancer to show how to use `mitology` to perform an analysis of the mitochondrial activity.

```{r, message=FALSE}
# loading packages
library(SummarizedExperiment)
library(AnnotationDbi)
library(org.Hs.eg.db)
library(GSVA)
library(Biobase)
```

```{r}
# load data
data(ovse)
ovse
```

### Enrichment analyses of the mitochondrial gene sets
We can perform an over representation analysis with `enrichMito`.

```{r, warning=FALSE}
genes <- rownames(ovse)[elementMetadata(ovse)$PROvsIMR_FDR < 0.01]
genes <- mapIds(
    org.Hs.eg.db, keys = genes, column = "ENSEMBL",
    keytype = "SYMBOL", multiVals = "first")

enrichresMC <- enrichMito(genes = genes, database = "MitoCarta")
enrichresRT <- enrichMito(genes = genes, database = "Reactome")
```

We can also compute the gene set enrichment analysis with `gseaMito`.
```{r, warning=FALSE}
geneslFC <- elementMetadata(ovse)$PROvsIMR_logFC
names(geneslFC) <- rownames(ovse)
names(geneslFC) <- mapIds(
    org.Hs.eg.db, keys = names(geneslFC), column = "ENSEMBL",
    keytype = "SYMBOL", multiVals = "first")
geneslFC <- sort(geneslFC, decreasing = TRUE)
geneslFC <- geneslFC[!is.na(names(geneslFC))]

gsearesMC <- gseaMito(genes = geneslFC, database = "MitoCarta")
gsearesRT <- gseaMito(genes = geneslFC, database = "Reactome")
```

Or also a single sample GSEA (ssGSEA) with `GSVA`.

```{r}
gsvaPar <- ssgseaParam(exprData = ovse, geneSets = MC_list)
res_ssGSEA <- gsva(gsvaPar)
```

## Visualization
The results obtained with the over representation analysis can be visualized with a dot plot over the database tree hierarchy.

```{r}
mitoTreePoint(data = enrichresMC, database = "MitoCarta", pvalCutoff = .9, color = "pvalue")
mitoTreePoint(data = enrichresRT, database = "Reactome", pvalCutoff = .4, color = "pvalue")
```

Instead, when we obtain a matrix of scores for each sample in each gene set we can visualize it in an heatmap.

Since we obtained a single score for each cell and it would be difficult to visualize it, we can summarize the information of samples by taking the mean value for each OV subtype.

```{r}
res_ssGSEA_subtype <- do.call(
    cbind, lapply(unique(ovse$OV_subtype), function(x){
        rowMeans(assay(res_ssGSEA)[,ovse$OV_subtype==x])
    }))
colnames(res_ssGSEA_subtype) <- unique(ovse$OV_subtype)
rownames(res_ssGSEA_subtype) <- rownames(res_ssGSEA)
res_ssGSEA_subtype <- t(scale(t(res_ssGSEA_subtype)))
```

```{r fig.height=5.5, fig.width=4.5}
mitoHeatmap(data = res_ssGSEA_subtype, database = "MitoCarta")
```

```{r fig.height=5.2, fig.width=5.5}
mitoHeatmap(data = res_ssGSEA_subtype, database = "MitoCarta", splitSections = TRUE)
```

We can also visualize it by plotting a circular heatmap on the gene set tree hierarchy.

```{r, message=FALSE}
mitoTreeHeatmap(
    data = res_ssGSEA_subtype, database = "MitoCarta",
    labelNames = "leaves", font.size = 1)
```

It is possible to plot only the main section arguments instead of the single gene set names.

```{r, message=FALSE}
mitoTreeHeatmap(
    data = res_ssGSEA_subtype, database = "MitoCarta",
    labelNames = "sections", font.size = 3)
```

These analysis can be done with the mitochondrial gene sets from Reactome, GO-CC and GO-BP.

# Bibliography
[1] Rath S, Sharma R, Gupta R, et al. MitoCarta3.0: an updated mitochondrial proteome now with sub-organelle localization and pathway annotations. Nucleic Acids Res 2020; 49:D1541–D1547

[2] Peck P. IMPI. 2021

[3] Shen L, Diroma MA, Gonzalez M, et al. MSeqDR: A Centralized Knowledge Repository and Bioinformatics Web Resource to Facilitate Genomic Investigations in Mitochondrial Disease. Hum Mutat 2016; 37:540–548

[4] The Gene Ontology Resource: 20 years and still GOing strong. Nucleic Acids Res 2019; 47:D330–D338

[5] Rothfels K, Milacic M, Matthews L, et al. Using the Reactome Database. Curr Protoc 2023; 3:e722

# Session Info
Here is the output of sessionInfo() on the system on which this document was compiled.

```{r}
sessionInfo()
```

---
title: "How we generate ovse object"
author: "Stefania Pirrotta"
date: '2025-01-28'
output: html_document
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = TRUE, message = FALSE)
```

In this workflow, we present all the steps, along with the code, to generate the `ovse` object: from sample collection and filtering to log fold change computation.

# Method
## Sample Collection
RNA sequencing Ovarian Cancer (OVC) data are retrieved from The Cancer Genome Atlas (TCGA) database using `curatedTCGAData` package. It returns a `MultiAssayExperiment`, from which we extract a `SummarizedExperiment.` Data are then normalized with the `betweenLaneNormalization` function.

```{r}
library(curatedTCGAData)
library(MultiAssayExperiment)
library(signifinder)
library(AnnotationDbi)
library(org.Hs.eg.db)
library(edgeR)

## Download data from TCGA
OVmae <- curatedTCGAData(diseaseCode = "OV", assays = "RNASeqGene", 
                         version = "2.0.1", dry.run = FALSE)
OVcolData <- colData(OVmae)
OVse <- OVmae[[1]]
colnames(OVse) <- substr(colnames(OVse), 1, 12)
OVse <- OVse[,!duplicated(colnames(OVse))]

## Normalize counts
assay(OVse) <- EDASeq::betweenLaneNormalization(as.matrix(assay(OVse)), 
                                                which = "median")
names(OVse@assays@data@listData)[1] <- "norm_expr"
```

Then, we compute the scores for the ovarian subgroups using the `consensusOVSign` function from `signifinder`, and we assign to each sample the subgroup with the highest score, following the procedure suggested by Chen et al, 2018, Clinical Cancer Research.
```{r}
## Compute consensusOV
OVse <- consensusOVSign(OVse)

cons_names <- c("ConsensusOV_Chen_IMR", "ConsensusOV_Chen_DIF", 
                "ConsensusOV_Chen_PRO", "ConsensusOV_Chen_MES")
OV_subtype <- sapply(1:296, function(x){
    names(which.max(as.vector(as.data.frame(colData(OVse))[x, cons_names])))})
OV_subtype <- substring(OV_subtype, 18)
names(OV_subtype) <- colnames(OVse)
```

## Sample and Gene Filtering
We select the 10 samples with the highest scores for each subgroup and filter out all the other samples.
```{r}
## Select few samples with the highest scores
selected_names <- c()
for(i in c("IMR", "DIF", "PRO", "MES")){
    sub_ov <- colData(OVse)[,paste0("ConsensusOV_Chen_", i)][OV_subtype==i]
    names(sub_ov) <- names(OV_subtype[OV_subtype==i])
    selected_names <- c(selected_names, 
                        names(sort(sub_ov, decreasing = T)[1:10]))
}
ovse <- OVse[, selected_names]
OV_subtype <- OV_subtype[selected_names]
```

To speed up the computation of the enrichment analyses, we keep only the genes included in the mitochondrial gene list and filter out all the other genes.
```{r}
## Select genes included in the signatures
genes_to_keep <- unlist(mapIds(
  x = org.Hs.eg.db, keys = MitoGenes, 
  column = "SYMBOL", keytype = "ENSEMBL", multiVals = "first"))
genes_to_keep <- unique(genes_to_keep)

## Filter genes
ovse <- ovse[rownames(ovse) %in% genes_to_keep,]
```

## Log fold change computation
We compute the log fold change of the IMR versus the PRO samples.
```{r}
dge <- DGEList(assay(ovse, i = 1))
dge <- calcNormFactors(dge, method = "RLE")
data_norm <- t(t(assay(ovse, i = 1))*dge$samples$norm.factors)
design <- model.matrix(~ 0+OV_subtype, data = colData(ovse))
dge <- estimateDisp(dge, design)
fit <- glmFit(dge, design)
res <- glmLRT(fit, contrast = c(0,-1,0,1))
PROvsIMR <- topTags(res, n=Inf)$table
```

We can now add these data inside the `ovse` object.
```{r}
## Add information to ovse
colData(ovse) <- colData(ovse)[,-c(1,2,3,4)]
ovse$OV_subtype <- OV_subtype
rowData(ovse) <- cbind(rowData(ovse), PROvsIMR_logFC = PROvsIMR$logFC)
rowData(ovse) <- cbind(rowData(ovse), PROvsIMR_FDR = PROvsIMR$FDR)

## Change sample names
colnames(ovse) <- paste0("sample", 1:40)

ovse
```

And this is the `ovse` object inside mitology/data.

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analysis_and_plot.R
\name{gseaMito}
\alias{gseaMito}
\title{Mitochondrial GSEA of a gene list.}
\usage{
gseaMito(genes, database)
}
\arguments{
\item{genes}{order ranked gene vector named by ENSEMBL id.}

\item{database}{character string saying the database to use for the analysis.
Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".}
}
\value{
GSEA results for the mitochondrial gene sets.
}
\description{
Gene set enrichment analysis for the mitochondrial gene sets. 
For the Reactome, GO-CC and GO-BP databases it returns also the GSEA 
results for the corresponding original pathways.
}
\examples{
data(ovse)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{MitoGenesDB}
\alias{MitoGenesDB}
\title{Mitochondrial genes}
\format{
An object of class \code{data.frame} with 2996 rows and 3 columns.
}
\usage{
data(MitoGenesDB)
}
\description{
Here are listed all the final mitochondrial genes in ENSEMBL id, the 
corresponding SYMBOL id and the database from where they were collected.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analysis_and_plot.R
\name{getGeneSets}
\alias{getGeneSets}
\title{Get the mitochondrial gene sets}
\usage{
getGeneSets(
  database = "MitoCarta",
  nametype = "ENSEMBL",
  objectType = "list",
  sections = FALSE
)
}
\arguments{
\item{database}{character string saying the database to use for the analysis.
Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".}

\item{nametype}{character string saying the type of gene name ID. 
Either one of "SYMBOL", "ENTREZID" or "ENSEMBL".}

\item{objectType}{character string saying the type of needed object. 
Either one of "list" or "dataframe".}

\item{sections}{logical. Either to keep the aggregated gene set categories 
or the specific gene sets. Default is FALSE.}
}
\value{
the mitochondrial gene sets.
}
\description{
It returns the mitochondrial gene sets (in form of list or 
data frame) of the four possible databases: "MitoCarta", "Reactome", 
"GO-CC" and "GO-BP".
}
\examples{
MClist <- getGeneSets()

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analysis_and_plot.R
\name{mitoTreeHeatmap}
\alias{mitoTreeHeatmap}
\title{Circular heatmap on mitochondrial gene set tree.}
\usage{
mitoTreeHeatmap(
  data,
  database = "MitoCarta",
  sections = FALSE,
  samples = NULL,
  labelNames = "sections",
  ...
)
}
\arguments{
\item{data}{matrix or data.frame with samples in columns and mitochondrial 
gene sets in rows.}

\item{database}{character string saying the database used for the analysis.
Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".}

\item{sections}{logical. Either to keep the aggregated gene set categories 
or the specific gene sets. Default is FALSE.}

\item{samples}{character vector with the names of samples to be plotted.
Otherwise all samples are plotted.}

\item{labelNames}{character string that says to plot either the names of 
"sections" or "leaves".}

\item{...}{other arguments passed on to the \code{\link[ggtree]{gheatmap}}
function.}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
Given a matrix of scores, it returns a circular heatmap of
the mitochondrial gene sets (leaf of the database tree) or gene set 
groups (section of the database tree).
}
\examples{
MClist <- getGeneSets()
n <- length(names(MClist)) * 5
rmatrix <- matrix(rnorm(n, 0), ncol = 5)
rownames(rmatrix) <- names(MClist)
colnames(rmatrix) <- paste0("Sample_", seq_len(5))
mitoTreeHeatmap(data = rmatrix, database = "MitoCarta")

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analysis_and_plot.R
\name{mitoHeatmap}
\alias{mitoHeatmap}
\title{Heatmap of mitochondrial gene sets.}
\usage{
mitoHeatmap(
  data,
  database = "MitoCarta",
  sampleAnnot = NULL,
  splitSamples = FALSE,
  splitSections = FALSE,
  ...
)
}
\arguments{
\item{data}{matrix or data.frame with samples in columns and mitochondrial 
gene sets in rows.}

\item{database}{character string saying the database used for the analysis.
Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".}

\item{sampleAnnot}{character vector with samples' annotation.}

\item{splitSamples}{logical. If TRUE it splits samples by annotation.
sampleAnnot must be provided.}

\item{splitSections}{logical. If TRUE it splits gene sets by main section.}

\item{...}{other parameters specific of the function
\code{\link[ComplexHeatmap]{Heatmap}}.}
}
\value{
A \code{\link[ComplexHeatmap]{Heatmap-class}} object.
}
\description{
Given a matrix of scores, it returns a heatmap of
the mitochondrial gene sets.
}
\examples{
MClist <- getGeneSets()
n <- length(names(MClist)) * 5
rmatrix <- matrix(rnorm(n, 0), ncol = 5)
rownames(rmatrix) <- names(MClist)
colnames(rmatrix) <- paste0("Sample_", seq_len(5))
mitoHeatmap(data = rmatrix, database = "MitoCarta")

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{ovse}
\alias{ovse}
\title{Example expression data.}
\format{
An object of class \code{SummarizedExperiment} with 2388 rows and 40 columns.
}
\usage{
data(ovse)
}
\description{
This is an example dataset containing gene expression values (in normalized
counts) of 40 ovarian cancer (OVC) patients extracted
from the Cancer Genome Atlas (TCGA) database.
This dataset should be used only with example purpose.
RNA sequencing OVC data were retrieved using
\code{\link[curatedTCGAData]{curatedTCGAData}} package. Data were then
normalized with the \code{\link[EDASeq]{betweenLaneNormalization}} function.
To lighten the dataset, the \code{\link[signifinder]{consensusOVSign}}
function was computed, which return 4 different scores, one for each OVC
subtype (Chen et al, 2018, Clinical Cancer Research) and the 10 samples
with the highest scores were selected for each subgroup.
Further, only the mitochondrial genes included in mitology were kept.
Finally, the log fold change of the IMR versus the PRO samples were computed.
Further details in mitology/inst/scripts/howToGenerateOvse.Rmd.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analysis_and_plot.R
\name{mitoTreePoint}
\alias{mitoTreePoint}
\title{Circular dotplot on mitochondrial gene set tree.}
\usage{
mitoTreePoint(
  data,
  database = "MitoCarta",
  pvalCutoff = 0.05,
  labsize = 3,
  max_point_size = 4,
  color = "p.adjust"
)
}
\arguments{
\item{data}{named list of the result from enrichMito or gseaMito.}

\item{database}{character string saying the database to use for the analysis.
Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".}

\item{pvalCutoff}{pvalue cutoff to select enriched gene sets}

\item{labsize}{label size}

\item{max_point_size}{max point size}

\item{color}{variable used to color enriched terms, e.g. 'pvalue', 
'p.adjust' or 'NES'.}
}
\value{
A \code{\link[ggplot2]{ggplot}} object.
}
\description{
A circular dotplot of the mitochondrial enrichment results.
}
\examples{
data(ovse)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mitology-package.R
\docType{package}
\name{mitology-package}
\alias{mitology}
\alias{mitology-package}
\title{mitology: Study of mitochondrial activity from RNA-seq data}
\description{
mitology allows to study the mitochondrial activity throught high-throughput RNA-seq data. It is based on a collection of genes whose proteins localize in to the mitochondria. From these, mitology provides a reorganization of the pathways related to mitochondria activity from Reactome and Gene Ontology. Further a ready-to-use implementation of MitoCarta3.0 pathways is included.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/CaluraLab/mitology}
  \item Report bugs at \url{https://github.com/CaluraLab/mitology/issues}
}

}
\author{
\strong{Maintainer}: Stefania Pirrotta \email{stefania.pirrotta@unipd.it} (\href{https://orcid.org/0009-0004-0030-217X}{ORCID})

Authors:
\itemize{
  \item Enrica Calura \email{enrica.calura@unipd.it} (\href{https://orcid.org/0000-0001-8463-2432}{ORCID}) [funder]
}

}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analysis_and_plot.R
\name{enrichMito}
\alias{enrichMito}
\title{Mitochondrial Enrichment Analysis of a gene list.}
\usage{
enrichMito(genes, database)
}
\arguments{
\item{genes}{a vector of gene ENSEMBL id.}

\item{database}{character string saying the database to use for the analysis.
Either one of "MitoCarta", "Reactome", "GO-CC" and "GO-BP".}
}
\value{
enrichment analysis for the mitochondrial gene sets.
}
\description{
Given a vector of genes, this function will return the 
enrichment analysis for the mitochondrial gene sets after FDR control. For 
the Reactome, GO-CC and GO-BP databases it returns also the enrichment 
results for the corresponding original pathways.
}
\examples{
data(ovse)

}
